@@ -1,9 +1,10 @@
 package Catmandu::RDF;
 #ABSTRACT: Modules for handling RDF data within the Catmandu framework
-our $VERSION = '0.15'; #VERSION
+our $VERSION = '0.16'; #VERSION
 
 use namespace::clean;
 use Catmandu::Sane;
+use Catmandu::Util qw(is_instance);
 use Moo::Role;
 use RDF::NS;
 
@@ -15,6 +16,7 @@ our %TYPE_ALIAS = (
     Json => 'RDFJSON',
 );
 
+# todo use 'file' to guess type
 has type => (
     is => 'ro', 
     coerce => sub { my $t = ucfirst($_[0]); $TYPE_ALIAS{$t} // $t },
@@ -22,15 +24,16 @@ has type => (
 
 has ns => (
     is => 'ro', 
-    default => sub { RDF::NS->new() },
+    default => sub { RDF::NS->new },
     coerce => sub {
-        (!ref $_[0] or ref $_[0] ne 'RDF::NS') ? RDF::NS->new(@_) : $_[0];
+        return $_[0] if is_instance($_[0],'RDF::NS');
+        return if !$_[0];
+        return RDF::NS->new($_[0]);
     },
     handles => ['uri'],
 );
 
 
-
 1;
 
 __END__
@@ -45,7 +48,7 @@ Catmandu::RDF - Modules for handling RDF data within the Catmandu framework
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 DESCRIPTION
 
@@ -63,6 +66,10 @@ Serialize RDF data (as RDF/XML, RDF/JSON, Turtle, NTriples, RDFa...).
 RDF data must be provided in B<another RDF Encoding Form (aREF)> as 
 implemented with L<RDF::aREF>.
 
+=item L<Catmandu::Importer::RDF>
+
+Parse RDF data (RDF/XML, RDF/JSON, Turtle, NTriples...).
+
 =back
 
 =head1 SUGGESTED MODULES
@@ -72,10 +79,6 @@ comment if you miss them!
 
 =over 4
 
-=item C<Catmandu::Importer::RDF>
-
-Import serialized RDF data (RDF/XML, RDF/JSON, Turtle, NTriples, RDFa...).
-
 =item C<Catmandu::Importer::SPARQL>
 
 Import RDF data from a SPARQL endpoint.
@@ -92,7 +95,8 @@ Export RDF with HTTP PATCH.
 
 =head1 SEE ALSO
 
-L<Catmandu>, L<RDF::aREF>, L<RDF::Trine>, L<RDF::NS>
+This module is based on L<Catmandu>, L<RDF::aREF>, L<RDF::Trine>, and
+L<RDF::NS>.
 
 =head1 AUTHOR
 
